@@ -31,6 +31,7 @@ from streamlit.runtime.scriptrunner_utils.script_run_context import (
     ScriptRunContext,
     get_script_run_ctx,
 )
+from streamlit.string_util import is_emoji
 
 if TYPE_CHECKING:
     from streamlit.source_util import PageHash, PageInfo
@@ -67,13 +68,12 @@ def pages_from_nav_sections(
 ) -> list[StreamlitPage]:
     page_list = []
     for pages in nav_sections.values():
-        for page in pages:
-            page_list.append(page)
+        page_list.extend(pages.copy())
 
     return page_list
 
 
-def send_page_not_found(ctx: ScriptRunContext):
+def send_page_not_found(ctx: ScriptRunContext) -> None:
     msg = ForwardMsg()
     msg.page_not_found.page_name = ""
     ctx.enqueue(msg)
@@ -83,7 +83,7 @@ def send_page_not_found(ctx: ScriptRunContext):
 def navigation(
     pages: Sequence[PageType] | Mapping[SectionHeader, Sequence[PageType]],
     *,
-    position: Literal["sidebar", "hidden"] = "sidebar",
+    position: Literal["sidebar", "hidden", "top"] = "sidebar",
     expanded: bool = False,
 ) -> StreamlitPage:
     """
@@ -120,7 +120,8 @@ def navigation(
         To create labeled sections or page groupings within the navigation
         menu, ``pages`` must be a dictionary. Each key is the label of a
         section and each value is the list of page-like objects for
-        that section.
+        that section. If you use ``position="top"``, each grouping will be a
+        collapsible item in the navigation menu.
 
         When you use a string or path as a page-like object, they are
         internally passed to ``st.Page`` and converted to ``StreamlitPage``
@@ -128,10 +129,11 @@ def navigation(
         path inferred from its path or filename. To customize these attributes
         for your page, initialize your page with ``st.Page``.
 
-    position : "sidebar" or "hidden"
+    position : "sidebar", "top", or "hidden"
         The position of the navigation menu. If this is ``"sidebar"``
         (default), the navigation widget appears at the top of the sidebar. If
-        this is ``"hidden"``, the navigation widget is not displayed.
+        this is ``"top"``, the navigation appears in the top header of the app.
+        If this is ``"hidden"``, the navigation widget is not displayed.
 
         If there is only one page in ``pages``, the navigation will be hidden
         for any value of ``position``.
@@ -147,6 +149,8 @@ def navigation(
         ``expanded=False`` on a rerun, the menu will stay expanded and a
         collapse button will be displayed.
 
+        The parameter is only used when ``position="sidebar"``.
+
     Returns
     -------
     StreamlitPage
@@ -225,7 +229,38 @@ def navigation(
         https://doc-navigation-example-2.streamlit.app/
         height: 300px
 
-    **Example 3: Stateful widgets across multiple pages**
+
+    **Example 3: Use top navigation**
+
+    You can use the ``position`` parameter to place the navigation at the top
+    of the app. This is useful for apps with a lot of pages because it allows
+    you to create collapsible sections for each group of pages. The following
+    example uses the same directory structure as Example 2 and shows how to
+    create a top navigation menu.
+
+    ``streamlit_app.py``:
+
+    >>> import streamlit as st
+    >>>
+    >>> pages = {
+    ...     "Your account": [
+    ...         st.Page("create_account.py", title="Create your account"),
+    ...         st.Page("manage_account.py", title="Manage your account"),
+    ...     ],
+    ...     "Resources": [
+    ...         st.Page("learn.py", title="Learn about us"),
+    ...         st.Page("trial.py", title="Try it out"),
+    ...     ],
+    ... }
+    >>>
+    >>> pg = st.navigation(pages, position="top")
+    >>> pg.run()
+
+    .. output::
+        https://doc-navigation-top.streamlit.app/
+        height: 300px
+
+    **Example 4: Stateful widgets across multiple pages**
 
     Call widget functions in your entrypoint file when you want a widget to be
     stateful across pages. Assign keys to your common widgets and access their
@@ -256,6 +291,13 @@ def navigation(
     .. _st.Page: https://docs.streamlit.io/develop/api-reference/navigation/st.page
 
     """
+    # Validate position parameter
+    if not isinstance(position, str) or position not in ["sidebar", "hidden", "top"]:
+        raise StreamlitAPIException(
+            f'Invalid position "{position}". '
+            'The position parameter must be one of "sidebar", "hidden", or "top".'
+        )
+
     # Disable the use of the pages feature (ie disregard v1 behavior of Multipage Apps)
     PagesManager.uses_pages_directory = False
 
@@ -265,7 +307,7 @@ def navigation(
 def _navigation(
     pages: Sequence[PageType] | Mapping[SectionHeader, Sequence[PageType]],
     *,
-    position: Literal["sidebar", "hidden"],
+    position: Literal["sidebar", "hidden", "top"],
     expanded: bool,
 ) -> StreamlitPage:
     if isinstance(pages, Sequence):
@@ -274,7 +316,7 @@ def _navigation(
     else:
         nav_sections = {
             section: [convert_to_streamlit_page(p) for p in section_pages]
-            for section, section_pages in pages.items()
+            for section, section_pages in pages.items()  # ty: ignore[possibly-unbound-attribute]
         }
     page_list = pages_from_nav_sections(nav_sections)
 
@@ -311,14 +353,11 @@ def _navigation(
     # Build the pagehash-to-pageinfo mapping.
     for section_header in nav_sections:
         for page in nav_sections[section_header]:
-            if isinstance(page._page, Path):
-                script_path = str(page._page)
-            else:
-                script_path = ""
+            script_path = str(page._page) if isinstance(page._page, Path) else ""
 
             script_hash = page._script_hash
             if script_hash in pagehash_to_pageinfo:
-                # The page script hash is soley based on the url path
+                # The page script hash is solely based on the url path
                 # So duplicate page script hashes are due to duplicate url paths
                 raise StreamlitAPIException(
                     f"Multiple Pages specified with URL pathname {page.url_path}. "
@@ -335,12 +374,17 @@ def _navigation(
             }
 
     msg = ForwardMsg()
+    # Handle position logic correctly
     if position == "hidden":
         msg.navigation.position = NavigationProto.Position.HIDDEN
-    elif config.get_option("client.showSidebarNavigation") is False:
-        msg.navigation.position = NavigationProto.Position.HIDDEN
-    else:
-        msg.navigation.position = NavigationProto.Position.SIDEBAR
+    elif position == "top":
+        msg.navigation.position = NavigationProto.Position.TOP
+    elif position == "sidebar":
+        # Only apply config override if position is sidebar
+        if config.get_option("client.showSidebarNavigation") is False:
+            msg.navigation.position = NavigationProto.Position.HIDDEN
+        else:
+            msg.navigation.position = NavigationProto.Position.SIDEBAR
 
     msg.navigation.expanded = expanded
     msg.navigation.sections[:] = nav_sections.keys()
@@ -349,7 +393,7 @@ def _navigation(
             p = msg.navigation.app_pages.add()
             p.page_script_hash = page._script_hash
             p.page_name = page.title
-            p.icon = page.icon
+            p.icon = f"emoji:{page.icon}" if is_emoji(page.icon) else page.icon
             p.is_default = page._default
             p.section_header = section_header
             p.url_pathname = page.url_path
